@@ -26,14 +26,15 @@ from hpccm.building_blocks.gnu import gnu
 from hpccm.building_blocks.hdf5 import hdf5
 from hpccm.building_blocks.intel_mpi import intel_mpi
 from hpccm.building_blocks.intel_psxe import intel_psxe
-from hpccm.building_blocks.llvm import llvm
 from hpccm.building_blocks.knem import knem
 from hpccm.building_blocks.kokkos import kokkos
+from hpccm.building_blocks.libsim import libsim
+from hpccm.building_blocks.llvm import llvm
 from hpccm.building_blocks.mkl import mkl
 from hpccm.building_blocks.mlnx_ofed import mlnx_ofed
 from hpccm.building_blocks.mpich import mpich
-from hpccm.building_blocks.mvapich2 import mvapich2
 from hpccm.building_blocks.mvapich2_gdr import mvapich2_gdr
+from hpccm.building_blocks.mvapich2 import mvapich2
 from hpccm.building_blocks.netcdf import netcdf
 from hpccm.building_blocks.ofed import ofed
 from hpccm.building_blocks.openblas import openblas
@@ -43,6 +44,7 @@ from hpccm.building_blocks.pgi import pgi
 from hpccm.building_blocks.pip import pip
 from hpccm.building_blocks.pnetcdf import pnetcdf
 from hpccm.building_blocks.python import python
+from hpccm.building_blocks.scif import scif
 from hpccm.building_blocks.ucx import ucx
 from hpccm.building_blocks.xpmem import xpmem
 from hpccm.building_blocks.yum import yum
