@@ -25,15 +25,18 @@ import logging # pylint: disable=unused-import
 import os
 
 import hpccm.config
+import hpccm.templates.rm
+import hpccm.templates.tar
+import hpccm.templates.wget
 
+from hpccm.building_blocks.base import bb_base
 from hpccm.building_blocks.packages import packages
 from hpccm.common import linux_distro
 from hpccm.primitives.comment import comment
 from hpccm.primitives.shell import shell
-from hpccm.templates.tar import tar
-from hpccm.templates.wget import wget
 
-class mlnx_ofed(tar, wget):
+class mlnx_ofed(bb_base, hpccm.templates.rm, hpccm.templates.tar,
+                hpccm.templates.wget):
     """The `mlnx_ofed` building block downloads and installs the [Mellanox
     OpenFabrics Enterprise Distribution for
     Linux](http://www.mellanox.com/page/products_dyn?product_family=26).
@@ -74,11 +77,7 @@ class mlnx_ofed(tar, wget):
     def __init__(self, **kwargs):
         """Initialize building block"""
 
-        # Trouble getting MRO with kwargs working correctly, so just call
-        # the parent class constructors manually for now.
-        #super(mlnx_ofed, self).__init__(**kwargs)
-        tar.__init__(self, **kwargs)
-        wget.__init__(self, **kwargs)
+        super(mlnx_ofed, self).__init__(**kwargs)
 
         self.__baseurl = kwargs.get('baseurl',
                                     'http://content.mellanox.com/ofed')
@@ -96,25 +95,15 @@ class mlnx_ofed(tar, wget):
         # Construct the series of steps to execute
         self.__setup()
 
-    def __str__(self):
-        """String representation of the building block"""
+        # Fill in container instructions
+        self.__instructions()
 
-        instructions = []
-        instructions.append(comment(
-            'Mellanox OFED version {}'.format(self.__version)))
-        instructions.append(packages(ospackages=self.__ospackages))
-        instructions.append(shell(commands=self.__commands))
+    def __instructions(self):
+        """Fill in container instructions"""
 
-        return '\n'.join(str(x) for x in instructions)
-
-    def __cleanup_step(self, items=None):
-        """Cleanup temporary files"""
-
-        if not items: # pragma: no cover
-            logging.warning('items are not defined')
-            return ''
-
-        return 'rm -rf {}'.format(' '.join(items))
+        self += comment('Mellanox OFED version {}'.format(self.__version))
+        self += packages(ospackages=self.__ospackages)
+        self += shell(commands=self.__commands)
 
     def __distro(self):
         """Based on the Linux distribution, set values accordingly.  A user
@@ -190,7 +179,7 @@ class mlnx_ofed(tar, wget):
                                                 self.__pkglist))
 
         # Cleanup
-        self.__commands.append(self.__cleanup_step(
+        self.__commands.append(self.cleanup_step(
             items=[os.path.join(self.__wd, tarball),
                    os.path.join(self.__wd, self.__prefix)]))
 
